==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/ru_RU.koi8r/ru_RU.koi8r-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: ru_RU.koi8r-nls.php,v 1.8.2.3 2005/03/23 08:58:50 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['ru_RU.koi8r'] = 	'&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439; (KOI8-R)';

/**
 ** Alias for languages with different browser and gettext codes
 **/
	//$nls['alias']['ru'] = 		'ru_RU.koi8r';

/**
 ** Alias for languages which we substitte or send by NUKE
 **/
    
	//$nls['alias']['russian'] =		'ru_RU.koi8r';
	//$nls['alias']['rus'] =		'ru_RU.koi8r';

/**
 ** Charset
 **
 **/	
	
	$nls['charset']['ru_RU.koi8r'] =	'KOI8-R';
	
/**
 ** PHPnuke
 **/
	//$nls['phpnuke']['ru_RU'] = 		'russian';

/**
 ** postNuke
 **/
	//$nls['postnuke']['ru_RU'] = 		'rus';
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/ru_RU.koi8r/ru_RU.koi8r-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: ru_RU.koi8r-nls.php,v 1.12.2.2 2005/09/12 22:41:11 dmolavi Exp $
 */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	Russian
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['ru_RU.koi8r'] = 	'&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439; (KOI8-R)';

/**
 * Aliases for languages with different browser and gettext codes
 * Commtented out as its not the default.
 */
	//$nls['alias']['ru'] = 		'ru_RU.koi8r';

/**
 * Alias for languages which we substitte or send by NUKE, GeekLog or Mambo
 * Commtented out as its not the default.
 */
	//$nls['alias']['russian'] =		'ru_RU.koi8r';
	//$nls['alias']['rus'] =		'ru_RU.koi8r';

/**
 * Charset
 */
	$nls['charset']['ru_RU.koi8r'] =	'KOI8-R';

/**
 * PHPnuke
 */
	//$nls['phpnuke']['ru_RU'] = 		'russian';

/**
 * postNuke
 */
	//$nls['postnuke']['ru_RU'] = 		'rus';

?>
